==> hn-main-referee-api-1.0-20250825.060529-42-sources.jar: com/beiming/odr/referee/dto/responsedto/MediationInfoResDTO.java <==
package com.beiming.odr.referee.dto.responsedto;

import com.beiming.odr.referee.dto.MediationCasePersonnelDTO;
import com.beiming.odr.referee.dto.MediationCaseProgressDTO;
import com.beiming.odr.referee.dto.PetitionAgentDTO;
import com.beiming.odr.referee.enums.SubsidyStatusEnum;
import com.beiming.odr.referee.enums.UserRoleEnum;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * 调解信息查看响应参数
 *
 * @author DJQ 2018年6月27日
 */
@Data
@NoArgsConstructor
public class MediationInfoResDTO implements Serializable {

  private static final long serialVersionUID = -2185513732200103145L;

  private String currentCaseUserType; // 当前用户案件内的角色类型

  private Long caseId; // 案件ID
  private String caseNo; // 案件号
  /**
   * @see UserRoleEnum
   */
  private String creatorType; // 案件录入人的身份
  private Long creatorId;
  private Long createTime; // 登记时间
  private Long endTime;  //调解结束时间
  private String lawCaseStatus; // 案件状态
  private String lawCaseStatusCode; // 案件状态
  private String lawCaseStatusFullCode; // 案件状态
  private Integer approvalType; // 审批类型

  private String origin; // 案件来源
  private Long orgId; // 调解机构ID
  private String orgName; // 调解机构
  private String orgAreaCode; // 调解机构区域Code
  private Boolean orgConfirm; // 机构受理状态
  private String appeal; // 申请人诉求

  private String mediationType; // 调解类型
  private String disputeType; // 纠纷类型
  private String disputeTypeCode; // 纠纷类型Code
  private String disputeContent; // 纠纷描述

  private String tab; // 重新分配的标签 2018.10.10

  private String provCode; // 发生地代号：省
  private String cityCode; // 发生地代号：市
  private String areaCode; // 发生地代号：区
  private String streetCode; // 发生地代号：街道
  private String communityCode; // 生地代号：社区

  private String provName; // 发生地名称：省
  private String cityName; // 发生地名称：市
  private String areaName; // 发生地名称：区
  private String streetName; // 发生地名称：街道
  private String communityName; // 发生地名称：社区
  private String address; // 详细地址
  private String officialSealUrl; // 机构公章地址
  private Boolean hadUnreadMsg; // 聊天室未读消息标识

  private Integer isJudicialConfirmation; // 是否具有司法确认 针对机构来说的
  private List<MediationCasePersonnelDTO> applicants; // 申请人 + agentApplicants 申请人代理人
  private List<MediationCasePersonnelDTO> respondents; // 被申请人 + agentRespondents 被申请人代理人
  private PetitionAgentDTO petitionAgentUser; // 信访代理人
  private List<MediationActualResDTO> mediators; // 调解员
  private List<MediationCaseProgressDTO> progress; // 案件进度
  private List<CaseMaterialResDTO> documents; // 案件材料
  private ArrayList<CaseMeetingListResDTO> videos; // 调解记录（视频会议记录）
  private List<WorkbenchDocStatusResDTO> workbenchs; // 工作台信息：调解协议书、无异议调解方案、无争议事实确认协议
  private Boolean extendable; //是否可以申请延期
  private Boolean extendConformable; //是否可以确认延期
  private String citeCaseType;
  private String caseType;
  private String cprmAmount; //纠纷金额
  private String disputeAmount; //和解金额
  private List<String> filingType; //针对caseType来说的 可以具备的立案类型
  private String followPersonName;
  private String followPersonPhone;
  private Integer visit;
  private String difficultyLevel;
  private String specialGroups;
  /**
   * 案件表申请已案定补可操作状态 不可申请（默认）CANT_APPLY,可申请（调解成功且已归档时）CAN_APPLY,可重新申请（审核失败时）CAN_REAPPLY,等待确认到账（审核成功时）WAIT_CONFIRM_RECEIPT,已完成（确认到账后）FINISH;
   *
   * @see SubsidyStatusEnum
   */
  private String subsidyStatus;

  /**
   * 案件发生时间
   */
  private Date happenTime;

  /**
   * 是否简易案件 1是0否
   */
  private Integer simple;
  /**
   * 是否重新分配的标识字段
   */
  private Boolean isSuspend;
  /**
   * 是否转办到涉外 0 ：否，1：是
   */
  private Integer isTurnToSw;

  /**
   * 涉外odr案件ID
   */
  private Long swCaseId;

  private String swCaseNo;

  /**
   * 转办到涉外时间
   */
  private Date turnTime;
}

==> hn-main-referee-api-1.0-20250918.063301-57-sources.jar: com/beiming/odr/referee/dto/responsedto/MediationInfoResDTO.java <==
package com.beiming.odr.referee.dto.responsedto;

import com.beiming.odr.referee.dto.MediationCasePersonnelDTO;
import com.beiming.odr.referee.dto.MediationCaseProgressDTO;
import com.beiming.odr.referee.dto.PetitionAgentDTO;
import com.beiming.odr.referee.enums.ResolutionTypeEnum;
import com.beiming.odr.referee.enums.SubsidyStatusEnum;
import com.beiming.odr.referee.enums.ThirdPartyServicesEnum;
import com.beiming.odr.referee.enums.UserRoleEnum;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * 调解信息查看响应参数
 *
 * @author DJQ 2018年6月27日
 */
@Data
@NoArgsConstructor
public class MediationInfoResDTO implements Serializable {

  private static final long serialVersionUID = -2185513732200103145L;

  private String currentCaseUserType; // 当前用户案件内的角色类型

  private Long caseId; // 案件ID
  private String caseNo; // 案件号
  /**
   * @see UserRoleEnum
   */
  private String creatorType; // 案件录入人的身份
  private Long creatorId;
  private Long createTime; // 登记时间
  private Long endTime;  //调解结束时间
  private String lawCaseStatus; // 案件状态
  private String lawCaseStatusCode; // 案件状态
  private String lawCaseStatusFullCode; // 案件状态
  private Integer approvalType; // 审批类型

  private String origin; // 案件来源
  private Long orgId; // 调解机构ID
  private String orgName; // 调解机构
  private String orgAreaCode; // 调解机构区域Code
  private Boolean orgConfirm; // 机构受理状态
  private String appeal; // 申请人诉求

  private String mediationType; // 调解类型
  private String disputeType; // 纠纷类型
  private String disputeTypeCode; // 纠纷类型Code
  private String disputeContent; // 纠纷描述

  private String tab; // 重新分配的标签 2018.10.10

  private String provCode; // 发生地代号：省
  private String cityCode; // 发生地代号：市
  private String areaCode; // 发生地代号：区
  private String streetCode; // 发生地代号：街道
  private String communityCode; // 生地代号：社区

  private String provName; // 发生地名称：省
  private String cityName; // 发生地名称：市
  private String areaName; // 发生地名称：区
  private String streetName; // 发生地名称：街道
  private String communityName; // 发生地名称：社区
  private String address; // 详细地址
  private String officialSealUrl; // 机构公章地址
  private Boolean hadUnreadMsg; // 聊天室未读消息标识

  private Integer isJudicialConfirmation; // 是否具有司法确认 针对机构来说的
  private List<MediationCasePersonnelDTO> applicants; // 申请人 + agentApplicants 申请人代理人
  private List<MediationCasePersonnelDTO> respondents; // 被申请人 + agentRespondents 被申请人代理人
  private PetitionAgentDTO petitionAgentUser; // 信访代理人
  private List<MediationActualResDTO> mediators; // 调解员
  private List<MediationCaseProgressDTO> progress; // 案件进度
  private List<CaseMaterialResDTO> documents; // 案件材料
  private ArrayList<CaseMeetingListResDTO> videos; // 调解记录（视频会议记录）
  private List<WorkbenchDocStatusResDTO> workbenchs; // 工作台信息：调解协议书、无异议调解方案、无争议事实确认协议
  private Boolean extendable; //是否可以申请延期
  private Boolean extendConformable; //是否可以确认延期
  private String citeCaseType;
  private String caseType;
  private String cprmAmount; //纠纷金额
  private String disputeAmount; //和解金额
  private List<String> filingType; //针对caseType来说的 可以具备的立案类型
  private String followPersonName;
  private String followPersonPhone;
  private Integer visit;
  private String difficultyLevel;
  private String specialGroups;
  /**
   * 案件表申请已案定补可操作状态 不可申请（默认）CANT_APPLY,可申请（调解成功且已归档时）CAN_APPLY,可重新申请（审核失败时）CAN_REAPPLY,等待确认到账（审核成功时）WAIT_CONFIRM_RECEIPT,已完成（确认到账后）FINISH;
   *
   * @see SubsidyStatusEnum
   */
  private String subsidyStatus;

  /**
   * 案件发生时间
   */
  private Date happenTime;

  /**
   * 是否简易案件 1是0否
   */
  private Integer simple;
  /**
   * 是否重新分配的标识字段
   */
  private Boolean isSuspend;
  /**
   * 是否转办到涉外 0 ：否，1：是
   */
  private Integer isTurnToSw;

  /**
   * 涉外odr案件ID
   */
  private Long swCaseId;

  private String swCaseNo;

  /**
   * 转办到涉外时间
   */
  private Date turnTime;

  /**
   * 国家
   */
  private String country;

  /**
   * 国家代码
   */
  private String countryCode;

  /**
   * 案件类型
   */
  private ResolutionTypeEnum resolutionType;

  /**
   * 第三方服务选项
   */
  private List<ThirdPartyServicesEnum> thirdPartyServices;

  /**
   * 第三方服务选项
   */
  private String thirdPartyServicesStr;
}
